@@ -34,6 +34,7 @@ from sqlalchemy import orm
 
 from rattail.util import load_object
 from rattail.files import temp_path
+from rattail.mail import send_email
 
 
 class AppHandler(object):
@@ -210,6 +211,14 @@ class AppHandler(object):
         if value is not None:
             return value.strftime('%Y-%m-%d %I:%M:%S %p')
 
+    def send_email(self, key, data={}, **kwargs):
+        """
+        Send an email message of the given type.
+
+        See :func:`rattail.mail.send_email()` for more info.
+        """
+        send_email(self.config, key, data, **kwargs)
+
 
 class GenericHandler(object):
     """
