@@ -50,7 +50,12 @@ class CustomerOrderBatchHandler(BatchHandler):
     has_custom_product_autocomplete = False
 
     def get_case_size_for_product(self, product):
-        return product.case_size
+        if product.case_size:
+            return product.case_size
+
+        cost = product.cost
+        if cost:
+            return cost.case_size
 
     def custom_product_autocomplete(self, session, term, **kwargs):
         """
