@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -57,7 +57,13 @@ class ClienteleHandler(GenericHandler):
         """
         return person.only_customer(require=False)
 
-    def make_customer(self, person):
+    def get_person(self, customer):
+        """
+        Returns the person associated with the given customer, if there is one.
+        """
+        return customer.only_person(require=False)
+
+    def make_customer(self, person, **kwargs):
         """
         Create and return a new customer record.
         """
