@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -1023,7 +1023,14 @@ class MakeAppDir(Subcommand):
         if args.user:
             import pwd
             pwdata = pwd.getpwnam(args.user)
-        for name in ['data', 'log', 'sessions', 'work']:
+        folders = [
+            'data',
+            os.path.join('data', 'uploads'),
+            'log',
+            'sessions',
+            'work',
+        ]
+        for name in folders:
             path = os.path.join(app_path, name)
             if not os.path.exists(path):
                 os.mkdir(path)
@@ -1291,7 +1298,7 @@ class RunAndMail(Subcommand):
         except subprocess.CalledProcessError as error:
             output = error.output
             retcode = error.returncode
-            log.warn("command exited with code: %s", retcode)
+            log.warning("command exited with code: %s", retcode)
 
         if six.PY3:
             output = output.decode('ascii')
