@@ -32,7 +32,6 @@ import warnings
 
 import six
 import sqlalchemy as sa
-from sqlalchemy import orm
 
 from rattail.app import GenericHandler
 from rattail.time import make_utc
@@ -122,6 +121,52 @@ class PeopleHandler(GenericHandler):
             # person.set_primary_address(address)
         return address
 
+    def request_merge(self, user, removing_uuid, keeping_uuid, **kwargs):
+        """
+        Submit an officical merge request for two Person records.
+
+        The caller must obviously specify which is to be kept and
+        which removed, but really this is arbitrary, as the user
+        performing the merge is free to swap them around.
+        """
+        model = self.model
+        session = self.get_session(user)
+        merge = model.MergePeopleRequest()
+        merge.removing_uuid = removing_uuid
+        merge.keeping_uuid = keeping_uuid
+        merge.requested_by = user
+        merge.requested = make_utc()
+        session.add(merge)
+        session.flush()
+        self.notify_of_merge_request(merge)
+        return merge
+
+    def notify_of_merge_request(self, merge):
+        """
+        Send an email alert regarding a new merge request.
+        """
+        session = self.get_session(merge)
+        model = self.model
+
+        removing = session.query(model.Person).get(merge.removing_uuid)
+        keeping = session.query(model.Person).get(merge.keeping_uuid)
+
+        context = {
+            'user_display': merge.requested_by.display_name,
+            'removing_display': six.text_type(removing) if removing else "(not found)",
+            'keeping_display': six.text_type(keeping) if keeping else "(not found)",
+        }
+
+        url = self.config.base_url()
+        if url:
+            context['merge_request_url'] = '{}/people/merge-requests/{}'.format(url, merge.uuid)
+            if removing:
+                context['removing_url'] = '{}/people/{}/profile'.format(url, removing.uuid)
+            if keeping:
+                context['keeping_url'] = '{}/people/{}/profile'.format(url, keeping.uuid)
+
+        self.app.send_email('person_merge_request', context)
+
     def get_merge_preview_fields(self, **kwargs):
         """
         Returns a sequence of fields which will be used during a merge
@@ -222,7 +267,7 @@ class PeopleHandler(GenericHandler):
             keeping.users.append(user)
 
         # delete unwanted Person
-        session = orm.object_session(keeping)
+        session = self.get_session(keeping)
         session.delete(removing)
         session.flush()
 
@@ -232,7 +277,7 @@ class PeopleHandler(GenericHandler):
         """
         If there was a merge request(s) for this pair, mark it complete.
         """
-        session = orm.object_session(keeping)
+        session = self.get_session(keeping)
         model = self.model
         merge_requests = session.query(model.MergePeopleRequest)\
                                 .filter(sa.or_(
