@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2019 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -30,6 +30,7 @@ from openpyxl.styles import PatternFill
 
 from rattail.reporting import Report
 from rattail.excel import ExcelWriter
+from rattail.time import localtime
 
 
 class ExcelReport(Report):
@@ -117,12 +118,18 @@ class ExcelReport(Report):
         """
         Write the secondary "summary" sheet for the Excel output file.
         """
+        app = self.config.get_app()
+        now = localtime(self.config)
 
         summary = writer.create_sheet("Report Summary")
 
         summary.append([])
         summary.append([self.name])
 
+        summary.append([])
+        summary.append(["Generated:"])
+        summary.append([app.render_datetime(now)])
+
         summary.append([])
         summary.append(["Parameters:"])
         for key, value in params.items():
