@@ -3,12 +3,13 @@
 from __future__ import unicode_literals, absolute_import
 
 import os
+import shutil
 import time
+import tempfile
 from six.moves import queue
 from unittest import TestCase
 
 from mock import Mock, patch, call
-from fixture import TempIO
 
 from rattail.config import make_config, RattailConfig
 from rattail.filemon import actions
@@ -27,23 +28,32 @@ class TestAction(TestCase):
 class TestPerformActions(TestCase):
 
     def setUp(self):
-        self.tmp = TempIO()
+        self.tempdir = tempfile.mkdtemp()
         self.config = make_config([])
         self.config.set(u'rattail.filemon', u'monitor', u'foo')
-        self.config.set(u'rattail.filemon', u'foo.dirs', self.tmp)
+        self.config.set('rattail.filemon', 'foo.dirs', self.tempdir)
         self.config.set(u'rattail.filemon', u'foo.actions', u'noop')
         self.config.set(u'rattail.filemon', u'foo.action.noop.func', u'rattail.filemon.actions:noop')
         # Must delay creating the profile since doing it here would bypass our mock of noop.
 
+    def tearDown(self):
+        shutil.rmtree(self.tempdir)
+
+    def write_file(self, fname, content):
+        path = os.path.join(self.tempdir, fname)
+        with open(path, 'wt') as f:
+            f.write(content)
+        return path
+
     def get_profile(self, stop_on_error=False):
         profile = Profile(self.config, u'foo')
         profile.stop_on_error = stop_on_error
         profile.queue = Mock()
         profile.queue.get_nowait.side_effect = [
             queue.Empty, # for coverage sake; will be effectively skipped
-            self.tmp.putfile(u'file1', u''),
-            self.tmp.putfile(u'file2', u''),
-            self.tmp.putfile(u'file3', u''),
+            self.write_file('file1', ''),
+            self.write_file('file2', ''),
+            self.write_file('file3', ''),
             actions.StopProcessing,
             ]
         return profile
@@ -53,20 +63,20 @@ class TestPerformActions(TestCase):
         actions.perform_actions(profile)
         self.assertEqual(noop.call_count, 3)
         noop.assert_has_calls([
-                call(self.tmp.join(u'file1')),
-                call(self.tmp.join(u'file2')),
-                call(self.tmp.join(u'file3')),
+                call(os.path.join(self.tempdir, 'file1')),
+                call(os.path.join(self.tempdir, 'file2')),
+                call(os.path.join(self.tempdir, 'file3')),
                 ])
 
     def test_action_is_skipped_for_nonexistent_file(self, noop):
         profile = self.get_profile()
-        os.remove(self.tmp.join(u'file2'))
+        os.remove(os.path.join(self.tempdir, 'file2'))
         actions.perform_actions(profile)
         self.assertEqual(noop.call_count, 2)
         # no call for file2
         noop.assert_has_calls([
-                call(self.tmp.join(u'file1')),
-                call(self.tmp.join(u'file3')),
+                call(os.path.join(self.tempdir, 'file1')),
+                call(os.path.join(self.tempdir, 'file3')),
                 ])
 
     def test_action_which_raises_error_causes_subsequent_actions_to_be_skipped_for_same_file(self, noop):
@@ -76,9 +86,9 @@ class TestPerformActions(TestCase):
         # processing second file fails, so it shouldn't be deleted
         noop.side_effect = [None, RuntimeError, None]
         actions.perform_actions(profile)
-        self.assertFalse(os.path.exists(self.tmp.join(u'file1')))
-        self.assertTrue(os.path.exists(self.tmp.join(u'file2')))
-        self.assertFalse(os.path.exists(self.tmp.join(u'file3')))
+        self.assertFalse(os.path.exists(os.path.join(self.tempdir, 'file1')))
+        self.assertTrue(os.path.exists(os.path.join(self.tempdir, 'file2')))
+        self.assertFalse(os.path.exists(os.path.join(self.tempdir, 'file3')))
 
     def test_action_which_raises_error_causes_all_processing_to_stop_if_so_configured(self, noop):
         self.config.set(u'rattail.filemon', u'foo.actions', u'noop, delete')
@@ -89,12 +99,12 @@ class TestPerformActions(TestCase):
         actions.perform_actions(profile)
         self.assertEqual(noop.call_count, 2)
         noop.assert_has_calls([
-                call(self.tmp.join(u'file1')),
-                call(self.tmp.join(u'file2')),
+                call(os.path.join(self.tempdir, 'file1')),
+                call(os.path.join(self.tempdir, 'file2')),
                 ])
-        self.assertFalse(os.path.exists(self.tmp.join(u'file1')))
-        self.assertTrue(os.path.exists(self.tmp.join(u'file2')))
-        self.assertTrue(os.path.exists(self.tmp.join(u'file3')))
+        self.assertFalse(os.path.exists(os.path.join(self.tempdir, 'file1')))
+        self.assertTrue(os.path.exists(os.path.join(self.tempdir, 'file2')))
+        self.assertTrue(os.path.exists(os.path.join(self.tempdir, 'file3')))
 
 
 class TestInvokeAction(TestCase):
@@ -104,8 +114,17 @@ class TestInvokeAction(TestCase):
         self.action.config = RattailConfig()
         self.action.action = Mock(return_value=None)
         self.action.retry_attempts = 6
-        self.tmp = TempIO()
-        self.file = self.tmp.putfile(u'file', u'')
+        self.tempdir = tempfile.mkdtemp()
+        self.file = self.write_file('file', '')
+
+    def tearDown(self):
+        shutil.rmtree(self.tempdir)
+
+    def write_file(self, fname, content):
+        path = os.path.join(self.tempdir, fname)
+        with open(path, 'wt') as f:
+            f.write(content)
+        return path
 
     def test_action_which_succeeds_is_only_called_once(self):
         actions.invoke_action(self.action, self.file)
